@@ -60,7 +60,7 @@ impl ToString for OperationType {
             OperationType::ConstrainCommits => "Creating commit constraints",
             OperationType::DetectDuplicateCommits => "Checking for duplicate commits",
             OperationType::EvaluateRevset(revset) => {
-                return format!("Evaluating revset: {}", revset);
+                return format!("Evaluating revset: {revset}");
             }
             OperationType::FilterByTouchedPaths => "Filtering upstream commits by touched paths",
             OperationType::FilterCommits => "Filtering commits",
@@ -244,7 +244,7 @@ pub mod icons {
     pub const CHECKMARK: &str = "✓";
 
     /// Used to indicate a warning.
-    pub const EXCLAMATION: &str = "⚠️";
+    pub const EXCLAMATION: &str = "!";
 
     /// Used to indicate failure.
     ///
@@ -559,6 +559,23 @@ impl Effects {
         }
     }
 
+    /// Suppress output sent to the returned `Effects`.
+    pub fn suppress(&self) -> Self {
+        Self {
+            dest: OutputDest::Suppress,
+            ..self.clone()
+        }
+    }
+
+    /// Apply transformations to the returned `Effects` to support emitting
+    /// graphical output in the opposite of its usual order.
+    pub fn reverse_order(&self, reverse: bool) -> Self {
+        Self {
+            glyphs: self.glyphs.clone().reverse_order(reverse),
+            ..self.clone()
+        }
+    }
+
     /// Start reporting progress for the specified operation type.
     ///
     /// A progress spinner is shown until the returned `ProgressHandle` is
@@ -873,7 +890,7 @@ impl Write for OutputStream {
 
             OutputDest::BufferForTest { stdout, stderr: _ } => {
                 let mut buffer = stdout.lock().unwrap();
-                write!(buffer, "{}", s).unwrap();
+                write!(buffer, "{s}").unwrap();
             }
         }
         Ok(())
@@ -933,7 +950,7 @@ impl Write for ErrorStream {
 
             OutputDest::BufferForTest { stdout: _, stderr } => {
                 let mut buffer = stderr.lock().unwrap();
-                write!(buffer, "{}", s).unwrap();
+                write!(buffer, "{s}").unwrap();
             }
         }
         Ok(())
