@@ -14,7 +14,8 @@ use crate::core::eventlog::{EventLogDb, EventTransactionId};
 use crate::core::formatting::Pluralize;
 use crate::core::repo_ext::RepoExt;
 use crate::git::{
-    GitRunInfo, MaybeZeroOid, NonZeroOid, ReferenceName, Repo, ResolvedReferenceInfo,
+    BranchType, CategorizedReferenceName, GitRunInfo, MaybeZeroOid, NonZeroOid, ReferenceName,
+    Repo, ResolvedReferenceInfo,
 };
 use crate::util::ExitCode;
 
@@ -53,8 +54,7 @@ pub fn move_branches<'a>(
             MaybeZeroOid::NonZero(new_oid) => {
                 let new_commit = match repo.find_commit_or_fail(*new_oid).wrap_err_with(|| {
                     format!(
-                        "Could not find newly-rewritten commit with old OID: {:?}, new OID: {:?}",
-                        old_oid, new_oid,
+                        "Could not find newly-rewritten commit with old OID: {old_oid:?}, new OID: {new_oid:?}",
                     )
                 }) {
                     Ok(commit) => commit,
@@ -79,8 +79,8 @@ pub fn move_branches<'a>(
             }
 
             MaybeZeroOid::Zero => {
-                for name in names {
-                    if name == &main_branch_name {
+                for reference_name in names {
+                    if reference_name == &main_branch_name {
                         // Hack? Never delete the main branch. We probably got here by syncing the
                         // main branch with the upstream version, but all main branch commits were
                         // skipped. For a regular branch, we would delete the branch, but for the
@@ -109,24 +109,34 @@ pub fn move_branches<'a>(
                                 MaybeZeroOid::Zero
                             }
                         };
-                        branch_moves.push((*old_oid, target_oid, name));
+                        branch_moves.push((*old_oid, target_oid, reference_name));
                     } else {
-                        match repo.find_reference(name) {
-                            Ok(Some(mut reference)) => {
-                                if let Err(err) = reference.delete() {
-                                    branch_move_err = Some(eyre::eyre!(err));
-                                    break 'outer;
-                                }
+                        let branch_name = CategorizedReferenceName::new(reference_name);
+                        match branch_name {
+                            CategorizedReferenceName::RemoteBranch { .. }
+                            | CategorizedReferenceName::OtherRef { .. } => {
+                                warn!(?reference_name, "Not deleting non-local-branch reference");
                             }
-                            Ok(None) => {
-                                warn!(?name, "Reference not found, not deleting")
+                            CategorizedReferenceName::LocalBranch { .. } => {
+                                let branch_name = branch_name.remove_prefix()?;
+                                match repo.find_branch(&branch_name, BranchType::Local) {
+                                    Ok(Some(mut branch)) => {
+                                        if let Err(err) = branch.delete() {
+                                            branch_move_err = Some(eyre::eyre!(err));
+                                            break 'outer;
+                                        }
+                                    }
+                                    Ok(None) => {
+                                        warn!(?branch_name, "Branch not found, not deleting")
+                                    }
+                                    Err(err) => {
+                                        branch_move_err = Some(eyre::eyre!(err));
+                                        break 'outer;
+                                    }
+                                };
+                                branch_moves.push((*old_oid, MaybeZeroOid::Zero, reference_name));
                             }
-                            Err(err) => {
-                                branch_move_err = Some(eyre::eyre!(err));
-                                break 'outer;
-                            }
-                        };
-                        branch_moves.push((*old_oid, MaybeZeroOid::Zero, name));
+                        }
                     }
                 }
             }
@@ -313,19 +323,31 @@ pub enum MergeConflictRemediation {
 
     /// Indicate that the user should run `git restack --merge`.
     Restack,
+
+    /// Indicate that the user should run `git move -m -s 'siblings(.)'`.
+    Insert,
 }
 
-/// Information about a merge conflict that occurred while moving commits.
+/// Information about a failure to merge that occurred while moving commits.
 #[derive(Debug)]
-pub struct MergeConflictInfo {
-    /// The OID of the commit that, when moved, caused a conflict.
-    pub commit_oid: NonZeroOid,
+pub enum FailedMergeInfo {
+    /// A merge conflict occurred.
+    Conflict {
+        /// The OID of the commit that, when moved, caused a conflict.
+        commit_oid: NonZeroOid,
 
-    /// The paths which were in conflict.
-    pub conflicting_paths: HashSet<PathBuf>,
+        /// The paths which were in conflict.
+        conflicting_paths: HashSet<PathBuf>,
+    },
+
+    /// A merge commit could not be rebased in memory.
+    CannotRebaseMergeInMemory {
+        /// The OID of the merge commit that could not be moved.
+        commit_oid: NonZeroOid,
+    },
 }
 
-impl MergeConflictInfo {
+impl FailedMergeInfo {
     /// Describe the merge conflict in a user-friendly way and advise to rerun
     /// with `--merge`.
     pub fn describe(
@@ -334,23 +356,44 @@ impl MergeConflictInfo {
         repo: &Repo,
         remediation: MergeConflictRemediation,
     ) -> eyre::Result<()> {
-        writeln!(
-            effects.get_output_stream(),
-            "This operation would cause a merge conflict:"
-        )?;
-        writeln!(
-            effects.get_output_stream(),
-            "{} ({}) {}",
-            effects.get_glyphs().bullet_point,
-            Pluralize {
-                determiner: None,
-                amount: self.conflicting_paths.len(),
-                unit: ("conflicting file", "conflicting files"),
-            },
-            effects.get_glyphs().render(
-                repo.friendly_describe_commit_from_oid(effects.get_glyphs(), self.commit_oid)?
-            )?
-        )?;
+        match self {
+            FailedMergeInfo::Conflict {
+                commit_oid,
+                conflicting_paths,
+            } => {
+                writeln!(
+                    effects.get_output_stream(),
+                    "This operation would cause a merge conflict:"
+                )?;
+                writeln!(
+                    effects.get_output_stream(),
+                    "{} ({}) {}",
+                    effects.get_glyphs().bullet_point,
+                    Pluralize {
+                        determiner: None,
+                        amount: conflicting_paths.len(),
+                        unit: ("conflicting file", "conflicting files"),
+                    },
+                    effects.get_glyphs().render(
+                        repo.friendly_describe_commit_from_oid(effects.get_glyphs(), *commit_oid)?
+                    )?
+                )?;
+            }
+
+            FailedMergeInfo::CannotRebaseMergeInMemory { commit_oid } => {
+                writeln!(
+                    effects.get_output_stream(),
+                    "Merge commits currently can't be rebased in-memory."
+                )?;
+                writeln!(
+                    effects.get_output_stream(),
+                    "The merge commit was: {}",
+                    effects.get_glyphs().render(
+                        repo.friendly_describe_commit_from_oid(effects.get_glyphs(), *commit_oid)?
+                    )?,
+                )?;
+            }
+        }
 
         match remediation {
             MergeConflictRemediation::Retry => {
@@ -365,6 +408,12 @@ impl MergeConflictInfo {
                     "To resolve merge conflicts, run: git restack --merge"
                 )?;
             }
+            MergeConflictRemediation::Insert => {
+                writeln!(
+                    effects.get_output_stream(),
+                    "To resolve merge conflicts, run: git move -m -s 'siblings(.)'"
+                )?;
+            }
         }
 
         Ok(())
@@ -390,7 +439,7 @@ mod in_memory {
     };
     use crate::util::ExitCode;
 
-    use super::{ExecuteRebasePlanOptions, MergeConflictInfo};
+    use super::{ExecuteRebasePlanOptions, FailedMergeInfo};
 
     pub enum RebaseInMemoryResult {
         Succeeded {
@@ -403,10 +452,7 @@ mod in_memory {
             /// caller will need to figure that out.
             new_head_oid: Option<NonZeroOid>,
         },
-        CannotRebaseMergeCommit {
-            commit_oid: NonZeroOid,
-        },
-        MergeConflict(MergeConflictInfo),
+        MergeFailed(FailedMergeInfo),
     }
 
     #[instrument]
@@ -422,29 +468,24 @@ mod in_memory {
                 .iter()
                 .find_map(|command| match command {
                     RebaseCommand::Merge {
-                        replacement_commit_oid: None,
                         commit_oid,
                         commits_to_merge: _,
                     } => Some(commit_oid),
-                    RebaseCommand::Merge {
-                        // If we know exactly what tree to use, we don't
-                        // actually have to carry out a merge in memory.
-                        replacement_commit_oid: Some(_),
-                        commit_oid: _,
-                        commits_to_merge: _,
-                    }
-                    | RebaseCommand::CreateLabel { .. }
+                    RebaseCommand::CreateLabel { .. }
                     | RebaseCommand::Reset { .. }
                     | RebaseCommand::Pick { .. }
+                    | RebaseCommand::Replace { .. }
                     | RebaseCommand::Break
                     | RebaseCommand::RegisterExtraPostRewriteHook
                     | RebaseCommand::DetectEmptyCommit { .. }
                     | RebaseCommand::SkipUpstreamAppliedCommit { .. } => None,
                 })
         {
-            return Ok(RebaseInMemoryResult::CannotRebaseMergeCommit {
-                commit_oid: *merge_commit_oid,
-            });
+            return Ok(RebaseInMemoryResult::MergeFailed(
+                FailedMergeInfo::CannotRebaseMergeInMemory {
+                    commit_oid: *merge_commit_oid,
+                },
+            ));
         }
 
         let ExecuteRebasePlanOptions {
@@ -488,6 +529,7 @@ mod in_memory {
                 | RebaseCommand::DetectEmptyCommit { .. } => false,
                 RebaseCommand::Pick { .. }
                 | RebaseCommand::Merge { .. }
+                | RebaseCommand::Replace { .. }
                 | RebaseCommand::SkipUpstreamAppliedCommit { .. } => true,
             })
             .count();
@@ -529,7 +571,7 @@ mod in_memory {
                     let commit_description = effects
                         .get_glyphs()
                         .render(commit_to_apply.friendly_describe(effects.get_glyphs())?)?;
-                    let commit_num = format!("[{}/{}]", i, num_picks);
+                    let commit_num = format!("[{i}/{num_picks}]");
                     progress.notify_progress(i, num_picks);
 
                     if commit_to_apply.get_parent_count() > 1 {
@@ -537,14 +579,16 @@ mod in_memory {
                             ?commit_to_apply_oid,
                             "BUG: Merge commit should have been detected during planning phase"
                         );
-                        return Ok(RebaseInMemoryResult::CannotRebaseMergeCommit {
-                            commit_oid: *commit_to_apply_oid,
-                        });
+                        return Ok(RebaseInMemoryResult::MergeFailed(
+                            FailedMergeInfo::CannotRebaseMergeInMemory {
+                                commit_oid: *commit_to_apply_oid,
+                            },
+                        ));
                     };
 
                     progress.notify_status(
                         OperationIcon::InProgress,
-                        format!("Applying patch for commit: {}", commit_description),
+                        format!("Applying patch for commit: {commit_description}"),
                     );
                     let commit_tree = match repo.cherry_pick_fast(
                         &commit_to_apply,
@@ -555,10 +599,12 @@ mod in_memory {
                     ) {
                         Ok(rebased_commit) => rebased_commit,
                         Err(CherryPickFastError::MergeConflict { conflicting_paths }) => {
-                            return Ok(RebaseInMemoryResult::MergeConflict(MergeConflictInfo {
-                                commit_oid: *commit_to_apply_oid,
-                                conflicting_paths,
-                            }))
+                            return Ok(RebaseInMemoryResult::MergeFailed(
+                                FailedMergeInfo::Conflict {
+                                    commit_oid: *commit_to_apply_oid,
+                                    conflicting_paths,
+                                },
+                            ))
                         }
                         Err(other) => eyre::bail!(other),
                     };
@@ -573,7 +619,7 @@ mod in_memory {
 
                     progress.notify_status(
                         OperationIcon::InProgress,
-                        format!("Committing to repository: {}", commit_description),
+                        format!("Committing to repository: {commit_description}"),
                     );
                     let committer_signature = if *preserve_timestamps {
                         commit_to_apply.get_committer()
@@ -607,10 +653,7 @@ mod in_memory {
 
                         writeln!(
                             effects.get_output_stream(),
-                            "[{}/{}] Skipped now-empty commit: {}",
-                            i,
-                            num_picks,
-                            commit_description
+                            "[{i}/{num_picks}] Skipped now-empty commit: {commit_description}"
                         )?;
                     } else {
                         rewritten_oids.push((
@@ -621,15 +664,12 @@ mod in_memory {
 
                         writeln!(
                             effects.get_output_stream(),
-                            "{} Committed as: {}",
-                            commit_num,
-                            commit_description
+                            "{commit_num} Committed as: {commit_description}"
                         )?;
                     }
                 }
 
                 RebaseCommand::Merge {
-                    replacement_commit_oid: None,
                     commit_oid,
                     commits_to_merge: _,
                 } => {
@@ -637,78 +677,82 @@ mod in_memory {
                         ?commit_oid,
                         "BUG: Merge commit without replacement should have been detected when starting in-memory rebase"
                     );
-                    return Ok(RebaseInMemoryResult::CannotRebaseMergeCommit {
-                        commit_oid: *commit_oid,
-                    });
+                    return Ok(RebaseInMemoryResult::MergeFailed(
+                        FailedMergeInfo::CannotRebaseMergeInMemory {
+                            commit_oid: *commit_oid,
+                        },
+                    ));
                 }
 
-                RebaseCommand::Merge {
-                    replacement_commit_oid: Some(replacement_commit_oid),
+                RebaseCommand::Replace {
                     commit_oid,
-                    commits_to_merge,
+                    replacement_commit_oid,
+                    parents,
                 } => {
-                    let current_commit = repo
-                        .find_commit_or_fail(current_oid)
+                    let original_commit = repo
+                        .find_commit_or_fail(*commit_oid)
                         .wrap_err("Finding current commit")?;
-                    let commit_to_apply = repo
-                        .find_commit_or_fail(*replacement_commit_oid)
-                        .wrap_err("Finding commit to apply")?;
-                    i += 1;
-
-                    let commit_description = effects
+                    let original_commit_description = effects
                         .get_glyphs()
-                        .render(commit_to_apply.friendly_describe(effects.get_glyphs())?)?;
-                    let commit_num = format!("[{}/{}]", i, num_picks);
+                        .render(original_commit.friendly_describe(effects.get_glyphs())?)?;
+
+                    i += 1;
+                    let commit_num = format!("[{i}/{num_picks}]");
                     progress.notify_progress(i, num_picks);
-
                     progress.notify_status(
                         OperationIcon::InProgress,
-                        format!("Applying merge commit: {}", commit_description),
+                        format!("Replacing commit: {original_commit_description}"),
                     );
-                    let commit = repo.find_commit_or_fail(*replacement_commit_oid)?;
-                    let commit_tree = commit.get_tree()?;
-                    let commit_message = commit_to_apply.get_message_raw()?;
-                    let commit_message = commit_message.to_str().with_context(|| {
-                        eyre::eyre!(
-                            "Could not decode commit message for commit: {:?}",
-                            replacement_commit_oid,
-                        )
-                    })?;
 
+                    let replacement_commit = repo.find_commit_or_fail(*replacement_commit_oid)?;
+                    let replacement_tree = replacement_commit.get_tree()?;
+                    let replacement_message = replacement_commit.get_message_raw()?;
+                    let replacement_commit_message =
+                        replacement_message.to_str().with_context(|| {
+                            eyre::eyre!(
+                                "Could not decode commit message for replacement commit: {:?}",
+                                replacement_commit
+                            )
+                        })?;
+
+                    let replacement_commit_description = effects
+                        .get_glyphs()
+                        .render(replacement_commit.friendly_describe(effects.get_glyphs())?)?;
                     progress.notify_status(
                         OperationIcon::InProgress,
-                        format!("Committing to repository: {}", commit_description),
+                        format!("Committing to repository: {replacement_commit_description}"),
                     );
                     let committer_signature = if *preserve_timestamps {
-                        commit_to_apply.get_committer()
+                        replacement_commit.get_committer()
                     } else {
-                        commit_to_apply.get_committer().update_timestamp(*now)?
+                        replacement_commit.get_committer().update_timestamp(*now)?
                     };
                     let parents = {
-                        let mut result = vec![current_commit];
-                        for parent in commits_to_merge {
-                            let parent = match parent {
-                                OidOrLabel::Oid(oid) => repo.find_commit_or_fail(*oid)?,
+                        let mut result = Vec::new();
+                        for parent in parents {
+                            let parent_oid = match parent {
+                                OidOrLabel::Oid(oid) => *oid,
                                 OidOrLabel::Label(label) => {
                                     let oid = labels.get(label).ok_or_else(|| {
                                         eyre::eyre!(
                                             "Label {label} could not be resolved to a commit"
                                         )
                                     })?;
-                                    repo.find_commit_or_fail(*oid)?
+                                    *oid
                                 }
                             };
-                            result.push(parent);
+                            let parent_commit = repo.find_commit_or_fail(parent_oid)?;
+                            result.push(parent_commit);
                         }
                         result
                     };
                     let rebased_commit_oid = repo
                         .create_commit(
                             None,
-                            &commit_to_apply.get_author(),
+                            &replacement_commit.get_author(),
                             &committer_signature,
-                            commit_message,
-                            &commit_tree,
+                            replacement_commit_message,
+                            &replacement_tree,
                             parents.iter().collect(),
                         )
                         .wrap_err("Applying rebased commit")?;
@@ -725,9 +769,7 @@ mod in_memory {
 
                     writeln!(
                         effects.get_output_stream(),
-                        "{} Committed as: {}",
-                        commit_num,
-                        commit_description
+                        "{commit_num} Committed as: {commit_description}"
                     )?;
                 }
 
@@ -737,7 +779,7 @@ mod in_memory {
 
                 RebaseCommand::SkipUpstreamAppliedCommit { commit_oid } => {
                     i += 1;
-                    let commit_num = format!("[{}/{}]", i, num_picks);
+                    let commit_num = format!("[{i}/{num_picks}]");
 
                     let commit = repo.find_commit_or_fail(*commit_oid)?;
                     rewritten_oids.push((*commit_oid, MaybeZeroOid::Zero));
@@ -747,9 +789,7 @@ mod in_memory {
                     let commit_description = effects.get_glyphs().render(commit_description)?;
                     writeln!(
                         effects.get_output_stream(),
-                        "{} Skipped commit (was already applied upstream): {}",
-                        commit_num,
-                        commit_description
+                        "{commit_num} Skipped commit (was already applied upstream): {commit_description}"
                     )?;
                 }
 
@@ -856,7 +896,7 @@ mod in_memory {
         // produce a spurious abandoned-branch warning.
         let post_rewrite_stdin: String = rewritten_oids
             .iter()
-            .map(|(old_oid, new_oid)| format!("{} {}\n", old_oid, new_oid))
+            .map(|(old_oid, new_oid)| format!("{old_oid} {new_oid}\n"))
             .collect();
         let post_rewrite_stdin = BString::from(post_rewrite_stdin);
         git_run_info.run_hook(
@@ -1145,11 +1185,11 @@ pub enum ExecuteRebasePlanResult {
         rewritten_oids: Option<HashMap<NonZeroOid, MaybeZeroOid>>,
     },
 
-    /// The rebase operation encounter a merge conflict, and it was not
+    /// The rebase operation encounter a failure to merge, and it was not
     /// requested to try to resolve it.
     DeclinedToMerge {
-        /// Information about the merge conflict that occurred.
-        merge_conflict: MergeConflictInfo,
+        /// Information about the merge failure that occurred.
+        failed_merge_info: FailedMergeInfo,
     },
 
     /// The rebase operation failed.
@@ -1187,7 +1227,9 @@ pub fn execute_rebase_plan(
             "Attempting rebase in-memory..."
         )?;
 
-        match rebase_in_memory(effects, repo, rebase_plan, options)? {
+        let failed_merge_info = match rebase_in_memory(effects, repo, rebase_plan, options)? {
+            RebaseInMemoryResult::MergeFailed(failed_merge_info) => failed_merge_info,
+
             RebaseInMemoryResult::Succeeded {
                 rewritten_oids,
                 new_head_oid,
@@ -1216,47 +1258,10 @@ pub fn execute_rebase_plan(
                     rewritten_oids: Some(rewritten_oids),
                 });
             }
+        };
 
-            RebaseInMemoryResult::CannotRebaseMergeCommit { commit_oid } => {
-                writeln!(
-                    effects.get_output_stream(),
-                    "Merge commits currently can't be rebased in-memory."
-                )?;
-                writeln!(
-                    effects.get_output_stream(),
-                    "The merge commit was: {}",
-                    effects.get_glyphs().render(
-                        repo.friendly_describe_commit_from_oid(effects.get_glyphs(), commit_oid)?
-                    )?,
-                )?;
-            }
-
-            RebaseInMemoryResult::MergeConflict(merge_conflict) => {
-                if !resolve_merge_conflicts
-                    // If an in-memory rebase was forced, don't suggest to the user
-                    // that they can re-run with `--merge`, since that still won't
-                    // work.
-                    && !*force_in_memory
-                {
-                    return Ok(ExecuteRebasePlanResult::DeclinedToMerge { merge_conflict });
-                }
-
-                let MergeConflictInfo {
-                    commit_oid,
-                    conflicting_paths: _,
-                } = merge_conflict;
-                writeln!(
-                    effects.get_output_stream(),
-                    "There was a merge conflict, which currently can't be resolved when rebasing in-memory."
-                )?;
-                writeln!(
-                    effects.get_output_stream(),
-                    "The conflicting commit was: {}",
-                    effects.get_glyphs().render(
-                        repo.friendly_describe_commit_from_oid(effects.get_glyphs(), commit_oid)?
-                    )?,
-                )?;
-            }
+        if !resolve_merge_conflicts {
+            return Ok(ExecuteRebasePlanResult::DeclinedToMerge { failed_merge_info });
         }
 
         // The rebase has failed at this point, decide whether or not to try
@@ -1266,11 +1271,12 @@ pub fn execute_rebase_plan(
                 effects.get_output_stream(),
                 "Aborting since an in-memory rebase was requested."
             )?;
-            return Ok(ExecuteRebasePlanResult::Failed {
-                exit_code: ExitCode(1),
-            });
+            return Ok(ExecuteRebasePlanResult::DeclinedToMerge { failed_merge_info });
         } else {
-            writeln!(effects.get_output_stream(), "Trying again on-disk...")?;
+            writeln!(
+                effects.get_output_stream(),
+                "Failed to merge in-memory, trying again on-disk..."
+            )?;
         }
     }
 
@@ -1299,13 +1305,11 @@ Commit your changes and then try again.
             Err(Error::OperationAlreadyInProgress { operation_type }) => {
                 writeln!(
                     effects.get_output_stream(),
-                    "A {} operation is already in progress.",
-                    operation_type
+                    "A {operation_type} operation is already in progress."
                 )?;
                 writeln!(
                     effects.get_output_stream(),
-                    "Run git {0} --continue or git {0} --abort to resolve it and proceed.",
-                    operation_type
+                    "Run git {operation_type} --continue or git {operation_type} --abort to resolve it and proceed."
                 )?;
                 return Ok(ExecuteRebasePlanResult::Failed {
                     exit_code: ExitCode(1),
