@@ -5,13 +5,12 @@ use std::path::PathBuf;
 use std::sync::Arc;
 
 use chashmap::CHashMap;
-use eden_dag::DagAlgorithm;
 use eyre::Context;
 use itertools::Itertools;
 use rayon::{prelude::*, ThreadPool};
 use tracing::{instrument, warn};
 
-use crate::core::dag::{commit_set_to_vec, union_all, CommitSet, Dag};
+use crate::core::dag::{union_all, CommitSet, Dag};
 use crate::core::effects::{Effects, OperationType};
 use crate::core::formatting::Pluralize;
 use crate::core::rewrite::{RepoPool, RepoResource};
@@ -187,8 +186,8 @@ impl ToString for RebaseCommand {
 /// A token representing that the rebase plan has been checked for validity.
 #[derive(Clone, Debug)]
 pub struct RebasePlanPermissions {
-    build_options: BuildRebasePlanOptions,
-    allowed_commits: CommitSet,
+    pub(crate) build_options: BuildRebasePlanOptions,
+    pub(crate) allowed_commits: CommitSet,
 }
 
 impl RebasePlanPermissions {
@@ -200,12 +199,12 @@ impl RebasePlanPermissions {
     ) -> eyre::Result<Result<Self, BuildRebasePlanError>> {
         // This isn't necessary for correctness, but helps to produce a better
         // error message which indicates the magnitude of the issue.
-        let commits = dag.query().descendants(commits.clone())?;
+        let commits = dag.query_descendants(commits.clone())?;
 
         let public_commits = dag.query_public_commits_slow()?;
         if !build_options.force_rewrite_public_commits {
             let public_commits_to_move = public_commits.intersection(&commits);
-            if !public_commits_to_move.is_empty()? {
+            if !dag.set_is_empty(&public_commits_to_move)? {
                 return Ok(Err(BuildRebasePlanError::MovePublicCommits {
                     public_commits_to_move,
                 }));
@@ -217,14 +216,6 @@ impl RebasePlanPermissions {
             allowed_commits: commits,
         }))
     }
-
-    #[cfg(test)]
-    fn omnipotent_for_test(dag: &Dag, build_options: BuildRebasePlanOptions) -> eyre::Result<Self> {
-        Ok(Self {
-            build_options,
-            allowed_commits: dag.query().all()?,
-        })
-    }
 }
 
 /// Represents the commits (as OIDs) that will be used to build a rebase plan.
@@ -308,12 +299,11 @@ impl<'a> ConstraintGraph<'a> {
                     let commits_to_move: CommitSet = commits_to_move.into_iter().collect();
                     let source_children: CommitSet = self
                         .dag
-                        .query()
-                        .children(CommitSet::from(*children_of_oid))?
+                        .query_children(CommitSet::from(*children_of_oid))?
                         .difference(&commits_to_move);
                     let source_children = self.dag.filter_visible_commits(source_children)?;
 
-                    for child_oid in commit_set_to_vec(&source_children)? {
+                    for child_oid in self.dag.commit_set_to_vec(&source_children)? {
                         self.inner.entry(parent_oid).or_default().insert(child_oid);
                     }
                 }
@@ -339,10 +329,9 @@ impl<'a> ConstraintGraph<'a> {
     ) -> eyre::Result<()> {
         let children_oids = self
             .dag
-            .query()
-            .children(CommitSet::from(current_oid))?
+            .query_children(CommitSet::from(current_oid))?
             .intersection(visible_commits);
-        let children_oids = commit_set_to_vec(&children_oids)?;
+        let children_oids = self.dag.commit_set_to_vec(&children_oids)?;
         for child_oid in children_oids {
             if self.commits_to_move().contains(&child_oid) {
                 continue;
@@ -421,7 +410,7 @@ impl<'a> ConstraintGraph<'a> {
         } = &self.permissions;
         let commits_to_move: CommitSet = self.commits_to_move().into_iter().collect();
         let illegal_commits_to_move = commits_to_move.difference(allowed_commits);
-        if !illegal_commits_to_move.is_empty()? {
+        if !self.dag.set_is_empty(&illegal_commits_to_move)? {
             Ok(Err(BuildRebasePlanError::MoveIllegalCommits {
                 illegal_commits_to_move,
             }))
@@ -536,7 +525,7 @@ pub struct RebasePlanBuilder<'a> {
     /// Cache mapping from commit OID to the paths changed in the diff for that
     /// commit. The value is `None` if the commit doesn't have an associated
     /// diff (i.e. is a merge commit).
-    touched_paths_cache: Arc<CHashMap<NonZeroOid, Option<HashSet<PathBuf>>>>,
+    pub(crate) touched_paths_cache: Arc<CHashMap<NonZeroOid, Option<HashSet<PathBuf>>>>,
 }
 
 #[derive(Clone, Debug, PartialEq, Eq, PartialOrd, Ord)]
@@ -600,7 +589,7 @@ pub enum BuildRebasePlanError {
 
 impl BuildRebasePlanError {
     /// Write the error message to `out`.
-    pub fn describe(&self, effects: &Effects, repo: &Repo) -> eyre::Result<()> {
+    pub fn describe(&self, effects: &Effects, repo: &Repo, dag: &Dag) -> eyre::Result<()> {
         match self {
             BuildRebasePlanError::ConstraintCycle { cycle_oids } => {
                 writeln!(
@@ -640,9 +629,10 @@ impl BuildRebasePlanError {
             BuildRebasePlanError::MovePublicCommits {
                 public_commits_to_move,
             } => {
-                let example_bad_commit_oid = public_commits_to_move.first()?.ok_or_else(|| {
-                    eyre::eyre!("BUG: could not get OID of a public commit to move")
-                })?;
+                let example_bad_commit_oid =
+                    dag.set_first(public_commits_to_move)?.ok_or_else(|| {
+                        eyre::eyre!("BUG: could not get OID of a public commit to move")
+                    })?;
                 let example_bad_commit_oid = NonZeroOid::try_from(example_bad_commit_oid)?;
                 let example_bad_commit = repo.find_commit_or_fail(example_bad_commit_oid)?;
                 writeln!(
@@ -654,7 +644,7 @@ collaborators will have difficulty merging your changes.
 Retry with -f/--force-rewrite to proceed anyways.",
                     Pluralize {
                         determiner: None,
-                        amount: public_commits_to_move.count()?,
+                        amount: dag.set_count(public_commits_to_move)?,
                         unit: ("public commit", "public commits")
                     },
                     effects
@@ -672,7 +662,7 @@ Retry with -f/--force-rewrite to proceed anyways.",
 BUG: The following commits were planned to be moved but not verified:
 {:?}
 This is a bug. Please report it.",
-                    commit_set_to_vec(illegal_commits_to_move)
+                    dag.commit_set_to_vec(illegal_commits_to_move)?
                 )?;
             }
         }
@@ -1176,7 +1166,7 @@ impl<'a> RebasePlanBuilder<'a> {
             .iter()
             .map(|dest_oid| {
                 let commit_set: CommitSet = [current_oid, *dest_oid].into_iter().collect();
-                self.dag.query().gca_all(commit_set)
+                self.dag.query_gca_all(commit_set)
             })
             .try_collect()?;
         let merge_base_oids = union_all(&merge_base_oids);
@@ -1188,8 +1178,7 @@ impl<'a> RebasePlanBuilder<'a> {
             let (effects, _progress) = effects.start_operation(OperationType::WalkCommits);
             let _effects = effects;
             self.dag
-                .query()
-                .range(merge_base_oids, dest_oids.iter().copied().collect())
+                .query_range(merge_base_oids, dest_oids.iter().copied().collect())
                 .wrap_err("Calculating upstream commits")?
         };
 
@@ -1244,7 +1233,7 @@ impl<'a> RebasePlanBuilder<'a> {
         touched_commit_oids: Vec<NonZeroOid>,
     ) -> eyre::Result<Vec<Commit<'a>>> {
         let (effects, _progress) = effects.start_operation(OperationType::FilterCommits);
-        let path = commit_set_to_vec(&path)?;
+        let path = self.dag.commit_set_to_vec(&path)?;
 
         let touched_commits: Vec<Commit> = touched_commit_oids
             .into_iter()
@@ -1349,750 +1338,3 @@ impl<'a> RebasePlanBuilder<'a> {
         }
     }
 }
-
-#[cfg(test)]
-mod tests {
-    use std::sync::Mutex;
-    use std::time::SystemTime;
-
-    use rayon::ThreadPoolBuilder;
-
-    use crate::core::check_out::CheckOutCommitOptions;
-    use crate::core::eventlog::{EventLogDb, EventReplayer};
-    use crate::core::formatting::Glyphs;
-    use crate::core::repo_ext::RepoExt;
-    use crate::core::rewrite::{
-        execute_rebase_plan, ExecuteRebasePlanOptions, ExecuteRebasePlanResult,
-    };
-    use crate::testing::{make_git, Git};
-
-    use super::*;
-
-    #[test]
-    fn test_cache_shared_between_builders() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-
-        let effects = Effects::new_suppress_for_test(Glyphs::text());
-        let repo = git.get_repo()?;
-        let conn = repo.get_db_conn()?;
-        let event_log_db = EventLogDb::new(&conn)?;
-        let event_replayer = EventReplayer::from_event_log_db(&effects, &repo, &event_log_db)?;
-        let event_cursor = event_replayer.make_default_cursor();
-        let references_snapshot = repo.get_references_snapshot()?;
-        let dag = Dag::open_and_sync(
-            &effects,
-            &repo,
-            &event_replayer,
-            event_cursor,
-            &references_snapshot,
-        )?;
-
-        let build_options = BuildRebasePlanOptions {
-            force_rewrite_public_commits: true,
-            dump_rebase_constraints: false,
-            dump_rebase_plan: false,
-            detect_duplicate_commits_via_patch_id: true,
-        };
-        let permissions = RebasePlanPermissions::omnipotent_for_test(&dag, build_options)?;
-        let pool = ThreadPoolBuilder::new().build()?;
-        let repo_pool = RepoPool::new(RepoResource {
-            repo: Mutex::new(repo.try_clone()?),
-        });
-        let mut builder = RebasePlanBuilder::new(&dag, permissions);
-        let builder2 = builder.clone();
-        builder.move_subtree(test3_oid, vec![test1_oid])?;
-        let result = builder.build(&effects, &pool, &repo_pool)?;
-        let result = result.unwrap();
-        let _ignored: Option<RebasePlan> = result;
-        assert!(builder.touched_paths_cache.contains_key(&test1_oid));
-        assert!(builder2.touched_paths_cache.contains_key(&test1_oid));
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_subtree_again_overrides_previous_move() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        let test2_oid = git.commit_file("test2", 2)?;
-        git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_subtree(test4_oid, vec![test1_oid])?;
-            builder.move_subtree(test4_oid, vec![test2_oid])?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |
-        o 96d1c37 create test2.txt
-        |\
-        | @ 8556cef create test4.txt
-        |
-        o 70deb1e create test3.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_subtree_within_moved_subtree() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_subtree(test3_oid, vec![test1_oid])?;
-            builder.move_subtree(test4_oid, vec![test1_oid])?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | @ 8e71a64 create test4.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_subtree_within_moved_subtree_in_other_order() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_subtree(test4_oid, vec![test1_oid])?;
-            builder.move_subtree(test3_oid, vec![test1_oid])?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | @ 8e71a64 create test4.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_commit_again_overrides_previous_move() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        let test2_oid = git.commit_file("test2", 2)?;
-        git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_commit(test4_oid, test1_oid)?;
-            builder.move_commit(test4_oid, test2_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |
-        o 96d1c37 create test2.txt
-        |\
-        | @ 8556cef create test4.txt
-        |
-        o 70deb1e create test3.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_nonconsecutive_commits() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        git.commit_file("test4", 4)?;
-        let test5_oid = git.commit_file("test5", 5)?;
-        git.commit_file("test6", 6)?;
-
-        git.run(&["smartlog"])?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_commit(test3_oid, test1_oid)?;
-            builder.move_commit(test5_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o 4ec3989 create test5.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        o 8556cef create test4.txt
-        |
-        @ 0a34830 create test6.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_consecutive_commits() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        git.commit_file("test5", 5)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_commit(test3_oid, test1_oid)?;
-            builder.move_commit(test4_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o 8e71a64 create test4.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        @ f26f28e create test5.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_consecutive_commits_in_other_order() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        git.commit_file("test5", 5)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_commit(test4_oid, test1_oid)?;
-            builder.move_commit(test3_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o 8e71a64 create test4.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        @ f26f28e create test5.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_commit_and_one_child_leaves_other_child() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        git.detach_head()?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        git.run(&["checkout", &test3_oid.to_string()])?;
-        git.commit_file("test5", 5)?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        o 70deb1e create test3.txt
-        |\
-        | o 355e173 create test4.txt
-        |
-        @ 9ea1b36 create test5.txt
-        "###);
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_commit(test3_oid, test1_oid)?;
-            builder.move_commit(test4_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o 8e71a64 create test4.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        @ f26f28e create test5.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_commit_add_then_giving_it_a_child() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        git.commit_file("test4", 4)?;
-        let test5_oid = git.commit_file("test5", 5)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_commit(test3_oid, test1_oid)?;
-            builder.move_commit(test5_oid, test3_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o ad2c2fc create test3.txt
-        | |
-        | @ ee4aebf create test5.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        o 8556cef create test4.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_range_again_overrides_previous_move() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        let test2_oid = git.commit_file("test2", 2)?;
-        git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        let test5_oid = git.commit_file("test5", 5)?;
-        git.commit_file("test6", 6)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_range(test4_oid, test5_oid, test1_oid)?;
-            builder.move_range(test4_oid, test5_oid, test2_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |
-        o 96d1c37 create test2.txt
-        |\
-        | o 8556cef create test4.txt
-        | |
-        | o 566236a create test5.txt
-        |
-        o 70deb1e create test3.txt
-        |
-        @ 35928ae create test6.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_range_and_then_partial_beginning_range_again() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        let test5_oid = git.commit_file("test5", 5)?;
-        git.commit_file("test6", 6)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_range(test3_oid, test5_oid, test1_oid)?;
-            builder.move_range(test3_oid, test4_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-
-        // FIXME This output is correct mathematically, but feels like it should
-        // be incorrect. What *should* we be doing if the user moves 2 ranges w/
-        // the same source/root oid but different end oids??
-        //
-        // NOTE See also the next test for the other case: where the end of the
-        // range is moved again. That *does* feel correct.
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o ad2c2fc create test3.txt
-        | |
-        | o 2b45b52 create test4.txt
-        |
-        o 96d1c37 create test2.txt
-        |\
-        | @ 99a62a3 create test6.txt
-        |
-        o f26f28e create test5.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_range_and_then_partial_ending_range_again() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        let test5_oid = git.commit_file("test5", 5)?;
-        git.commit_file("test6", 6)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_range(test3_oid, test5_oid, test1_oid)?;
-            builder.move_range(test4_oid, test5_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o 8e71a64 create test4.txt
-        | |
-        | o 3d57d30 create test5.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        @ 99a62a3 create test6.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_subtree_and_commit_within_subtree() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        let _test2_oid = git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        let _test5_oid = git.commit_file("test5", 5)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_subtree(test3_oid, vec![test1_oid])?;
-            builder.move_commit(test4_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o 8e71a64 create test4.txt
-        |\
-        | o ad2c2fc create test3.txt
-        | |
-        | @ ee4aebf create test5.txt
-        |
-        o 96d1c37 create test2.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_subtree_and_then_its_parent_commit() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let test1_oid = git.commit_file("test1", 1)?;
-        let _test2_oid = git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        let _test5_oid = git.commit_file("test5", 5)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_subtree(test4_oid, vec![test1_oid])?;
-            builder.move_commit(test3_oid, test1_oid)?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |\
-        | o 8e71a64 create test4.txt
-        | |
-        | @ 3d57d30 create test5.txt
-        |\
-        | o ad2c2fc create test3.txt
-        |
-        o 96d1c37 create test2.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_subtree_to_descendant_of_itself() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let _test1_oid = git.commit_file("test1", 1)?;
-        let test2_oid = git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let _test4_oid = git.commit_file("test4", 4)?;
-        let test5_oid = git.commit_file("test5", 5)?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_subtree(test3_oid, vec![test5_oid])?;
-            builder.move_subtree(test5_oid, vec![test2_oid])?;
-            Ok(())
-        })?;
-
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |
-        o 96d1c37 create test2.txt
-        |
-        @ f26f28e create test5.txt
-        |
-        o 2b42d9c create test3.txt
-        |
-        o c533a65 create test4.txt
-        "###);
-
-        Ok(())
-    }
-
-    #[test]
-    fn test_plan_moving_subtree_with_merge_commit() -> eyre::Result<()> {
-        let git = make_git()?;
-        git.init_repo()?;
-        git.detach_head()?;
-        let _test1_oid = git.commit_file("test1", 1)?;
-        let test2_oid = git.commit_file("test2", 2)?;
-        let test3_oid = git.commit_file("test3", 3)?;
-        let test4_oid = git.commit_file("test4", 4)?;
-        git.run(&["checkout", "HEAD~"])?;
-        let _test5_oid = git.commit_file("test5", 5)?;
-        git.run(&["merge", &test4_oid.to_string()])?;
-        git.run(&["checkout", "HEAD~"])?;
-
-        create_and_execute_plan(&git, move |builder: &mut RebasePlanBuilder| {
-            builder.move_subtree(test3_oid, vec![test2_oid])?;
-            Ok(())
-        })?;
-
-        // FIXME: this is wrong, the merge commit should be moved as well.
-        let stdout = git.smartlog()?;
-        insta::assert_snapshot!(stdout, @r###"
-        O f777ecc (master) create initial.txt
-        |
-        o 62fc20d create test1.txt
-        |
-        o 96d1c37 create test2.txt
-        |\
-        | o b8f27a8 create test3.txt
-        | |\
-        | | @ 2b47b50 create test5.txt
-        | |
-        | o 22cf458 create test4.txt
-        |
-        x 70deb1e (rewritten as b8f27a86) create test3.txt
-        |\
-        | x 355e173 (rewritten as 22cf4586) create test4.txt
-        | & (merge) 8fb706a Merge commit '355e173bf9c5d2efac2e451da0cdad3fb82b869a' into HEAD
-        |
-        x 9ea1b36 (rewritten as 2b47b505) create test5.txt
-        |
-        | & (merge) 355e173 (rewritten as 22cf4586) create test4.txt
-        |/
-        o 8fb706a Merge commit '355e173bf9c5d2efac2e451da0cdad3fb82b869a' into HEAD
-        hint: there is 1 abandoned commit in your commit graph
-        hint: to fix this, run: git restack
-        hint: disable this hint by running: git config --global branchless.hint.smartlogFixAbandoned false
-        "###);
-
-        Ok(())
-    }
-
-    /// Helper function to handle the boilerplate involved in creating, building
-    /// and executing the rebase plan.
-    fn create_and_execute_plan(
-        git: &Git,
-        builder_callback_fn: impl Fn(&mut RebasePlanBuilder) -> eyre::Result<()>,
-    ) -> eyre::Result<()> {
-        let effects = Effects::new_suppress_for_test(Glyphs::text());
-        let repo = git.get_repo()?;
-        let conn = repo.get_db_conn()?;
-        let event_log_db = EventLogDb::new(&conn)?;
-        let event_replayer = EventReplayer::from_event_log_db(&effects, &repo, &event_log_db)?;
-        let event_cursor = event_replayer.make_default_cursor();
-        let references_snapshot = repo.get_references_snapshot()?;
-        let dag = Dag::open_and_sync(
-            &effects,
-            &repo,
-            &event_replayer,
-            event_cursor,
-            &references_snapshot,
-        )?;
-
-        let pool = ThreadPoolBuilder::new().build()?;
-        let repo_pool = RepoPool::new(RepoResource {
-            repo: Mutex::new(repo.try_clone()?),
-        });
-
-        let build_options = BuildRebasePlanOptions {
-            force_rewrite_public_commits: false,
-            dump_rebase_constraints: false,
-            dump_rebase_plan: false,
-            detect_duplicate_commits_via_patch_id: true,
-        };
-        let permissions = RebasePlanPermissions::omnipotent_for_test(&dag, build_options)?;
-        let mut builder = RebasePlanBuilder::new(&dag, permissions);
-
-        builder_callback_fn(&mut builder)?;
-
-        let build_result = builder.build(&effects, &pool, &repo_pool)?;
-
-        let rebase_plan = match build_result {
-            Ok(None) => return Ok(()),
-            Ok(Some(rebase_plan)) => rebase_plan,
-            Err(rebase_plan_error) => {
-                eyre::bail!("Error building rebase plan: {:#?}", rebase_plan_error)
-            }
-        };
-
-        let now = SystemTime::UNIX_EPOCH;
-        let options = ExecuteRebasePlanOptions {
-            now,
-            event_tx_id: event_log_db.make_transaction_id(now, "test plan")?,
-            preserve_timestamps: false,
-            force_in_memory: true,
-            force_on_disk: false,
-            resolve_merge_conflicts: false,
-            check_out_commit_options: CheckOutCommitOptions {
-                additional_args: Default::default(),
-                reset: false,
-                render_smartlog: false,
-            },
-        };
-        let git_run_info = git.get_git_run_info();
-        let result = execute_rebase_plan(
-            &effects,
-            &git_run_info,
-            &repo,
-            &event_log_db,
-            &rebase_plan,
-            &options,
-        )?;
-        assert!(matches!(
-            result,
-            ExecuteRebasePlanResult::Succeeded { rewritten_oids: _ }
-        ));
-
-        Ok(())
-    }
-}
