@@ -350,13 +350,12 @@ pub(super) fn eval_number_rhs(
 mod tests {
     use std::borrow::Cow;
 
-    use lib::core::dag::commit_set_to_vec;
+    use git_branchless_testing::{make_git, GitRunOptions};
     use lib::core::effects::Effects;
     use lib::core::eventlog::{EventLogDb, EventReplayer};
     use lib::core::formatting::Glyphs;
     use lib::core::repo_ext::RepoExt;
     use lib::git::Commit;
-    use lib::testing::{make_git, GitRunOptions};
 
     use super::*;
     use crate::Expr;
@@ -368,7 +367,8 @@ mod tests {
         expr: &Expr,
     ) -> eyre::Result<Vec<Commit<'a>>> {
         let result = eval(effects, repo, dag, expr)?;
-        let mut commits: Vec<Commit> = commit_set_to_vec(&result)?
+        let mut commits: Vec<Commit> = dag
+            .commit_set_to_vec(&result)?
             .into_iter()
             .map(|oid| repo.find_commit_or_fail(oid))
             .try_collect()?;
