@@ -1,7 +1,7 @@
 use std::collections::HashMap;
 
+use git_branchless_testing::{make_git, GitRunOptions};
 use itertools::Itertools;
-use lib::testing::{make_git, GitRunOptions};
 
 #[test]
 fn test_commands() -> eyre::Result<()> {
@@ -11,7 +11,7 @@ fn test_commands() -> eyre::Result<()> {
     git.commit_file("test", 1)?;
 
     {
-        let (stdout, _stderr) = git.run(&["smartlog"])?;
+        let stdout = git.smartlog()?;
         insta::assert_snapshot!(stdout, @r###"
         :
         @ 3df4b93 (> master) create test.txt
@@ -19,7 +19,7 @@ fn test_commands() -> eyre::Result<()> {
     }
 
     {
-        let (stdout, _stderr) = git.run(&["hide", "3df4b935"])?;
+        let (stdout, _stderr) = git.branchless("hide", &["3df4b935"])?;
         insta::assert_snapshot!(stdout, @r###"
         Hid commit: 3df4b93 create test.txt
         Abandoned 1 branch: master
@@ -28,7 +28,7 @@ fn test_commands() -> eyre::Result<()> {
     }
 
     {
-        let (stdout, _stderr) = git.run(&["unhide", "3df4b935"])?;
+        let (stdout, _stderr) = git.branchless("unhide", &["3df4b935"])?;
         insta::assert_snapshot!(stdout, @r###"
         Unhid commit: 3df4b93 create test.txt
         To hide this 1 commit, run: git undo
@@ -36,7 +36,7 @@ fn test_commands() -> eyre::Result<()> {
     }
 
     {
-        let (stdout, _stderr) = git.run(&["prev"])?;
+        let (stdout, _stderr) = git.branchless("prev", &[])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout f777ecc9b0db5ed372b2615695191a8a17f79f24
         @ f777ecc create initial.txt
@@ -46,7 +46,7 @@ fn test_commands() -> eyre::Result<()> {
     }
 
     {
-        let (stdout, _stderr) = git.run(&["next"])?;
+        let (stdout, _stderr) = git.branchless("next", &[])?;
         insta::assert_snapshot!(stdout, @r###"
         branchless: running command: <git-executable> checkout master
         :
@@ -62,8 +62,9 @@ fn test_profiling() -> eyre::Result<()> {
     let git = make_git()?;
     git.init_repo()?;
 
-    git.run_with_options(
-        &["smartlog"],
+    git.branchless_with_options(
+        "smartlog",
+        &[],
         &GitRunOptions {
             env: {
                 let mut env: HashMap<String, String> = HashMap::new();
@@ -74,9 +75,7 @@ fn test_profiling() -> eyre::Result<()> {
         },
     )?;
 
-    let entries: Vec<_> = std::fs::read_dir(&git.repo_path)?
-        .into_iter()
-        .try_collect()?;
+    let entries: Vec<_> = std::fs::read_dir(&git.repo_path)?.try_collect()?;
     assert!(entries
         .iter()
         .any(|entry| entry.file_name().to_str().unwrap().contains("trace-")));
@@ -100,12 +99,13 @@ fn test_sparse_checkout() -> eyre::Result<()> {
         "###);
     }
 
-    if let Ok((stdout, _stderr)) = git.run(&["smartlog"]) {
+    if let Ok(stdout) = git.smartlog() {
         insta::assert_snapshot!(stdout, @"@ f777ecc (> master) create initial.txt
 ");
     } else {
-        let (stdout, _stderr) = git.run_with_options(
-            &["smartlog"],
+        let (stdout, _stderr) = git.branchless_with_options(
+            "smartlog",
+            &[],
             &GitRunOptions {
                 expected_exit_code: 1,
                 ..Default::default()
